==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesVipPoolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endIP Ending IP address for the IP Pool
 * @property startIP Starting IP address for the IP Pool
 */
public data class VirtualNetworksPropertiesVipPoolArgs(
    public val endIP: Output<String>? = null,
    public val startIP: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs.builder()
            .endIP(endIP?.applyValue({ args0 -> args0 }))
            .startIP(startIP?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworksPropertiesVipPoolArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesVipPoolArgsBuilder internal constructor() {
    private var endIP: Output<String>? = null

    private var startIP: Output<String>? = null

    /**
     * @param value Ending IP address for the IP Pool
     */
    @JvmName("nuqsufuugiaysivd")
    public suspend fun endIP(`value`: Output<String>) {
        this.endIP = value
    }

    /**
     * @param value Starting IP address for the IP Pool
     */
    @JvmName("qibimwmplkhfrmyh")
    public suspend fun startIP(`value`: Output<String>) {
        this.startIP = value
    }

    /**
     * @param value Ending IP address for the IP Pool
     */
    @JvmName("hodnbkvtbbsvusmh")
    public suspend fun endIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endIP = mapped
    }

    /**
     * @param value Starting IP address for the IP Pool
     */
    @JvmName("rdrysuwwjmixbxff")
    public suspend fun startIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startIP = mapped
    }

    internal fun build(): VirtualNetworksPropertiesVipPoolArgs = VirtualNetworksPropertiesVipPoolArgs(
        endIP = endIP,
        startIP = startIP,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesVipPoolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endIP Ending IP address for the IP Pool
 * @property startIP Starting IP address for the IP Pool
 */
public data class VirtualNetworksPropertiesVipPoolArgs(
    public val endIP: Output<String>? = null,
    public val startIP: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesVipPoolArgs.builder()
            .endIP(endIP?.applyValue({ args0 -> args0 }))
            .startIP(startIP?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworksPropertiesVipPoolArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesVipPoolArgsBuilder internal constructor() {
    private var endIP: Output<String>? = null

    private var startIP: Output<String>? = null

    /**
     * @param value Ending IP address for the IP Pool
     */
    @JvmName("huwogahxkmwgopuw")
    public suspend fun endIP(`value`: Output<String>) {
        this.endIP = value
    }

    /**
     * @param value Starting IP address for the IP Pool
     */
    @JvmName("rsymqnwsaxadwaxb")
    public suspend fun startIP(`value`: Output<String>) {
        this.startIP = value
    }

    /**
     * @param value Ending IP address for the IP Pool
     */
    @JvmName("cjsctxmivkuxxpup")
    public suspend fun endIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endIP = mapped
    }

    /**
     * @param value Starting IP address for the IP Pool
     */
    @JvmName("wuvmwvcnjqxpgtja")
    public suspend fun startIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startIP = mapped
    }

    internal fun build(): VirtualNetworksPropertiesVipPoolArgs = VirtualNetworksPropertiesVipPoolArgs(
        endIP = endIP,
        startIP = startIP,
    )
}
